@@ -22,8 +22,8 @@
 Tools for extracting, cleaning, transforming and validating ISBN ids.
 """
 
-import re
 import logging
+import re
 
 LOGGER = logging.getLogger(__name__)
 
@@ -118,8 +118,11 @@ def is_isbn13(isbn13):
 
 def to_isbn10(isbn13):
     """Transform isbn-13 to isbn-10."""
+    isbn13 = canonical(isbn13)
     # Check prefix
     if isbn13[:3] != ISBN13_PREFIX:
+        return isbn13 if len(isbn13) == 10 and is_isbn10(isbn13) else None
+    if not is_isbn13(isbn13):
         return None
     isbn10 = isbn13[3:]
     check = _check_digit10(isbn10[:-1])
@@ -129,6 +132,11 @@ def to_isbn10(isbn13):
 
 def to_isbn13(isbn10):
     """Transform isbn-10 to isbn-13."""
+    isbn10 = canonical(isbn10)
+    if len(isbn10) == 13 and is_isbn13(isbn10):
+        return isbn10
+    if not is_isbn10(isbn10):
+        return None
     isbn13 = ISBN13_PREFIX + isbn10[:-1]
     check = _check_digit13(isbn13)
     return isbn13 + check if check else None
@@ -157,7 +165,7 @@ def notisbn(isbnlike, level='strict'):
     loose  only filters obvious NO ISBNs
 
     """
-    if level not in ('strict', 'loose'):
+    if level not in ('strict', 'loose'):  # pragma: no cover
         LOGGER.error('level as no option %s', level)
         return
     isbnlike = canonical(isbnlike)
@@ -180,7 +188,7 @@ def get_isbnlike(text, level='normal'):
     loose  catch many as possible
 
     """
-    if level == 'normal':
+    if level == 'normal':  # pragma: no cover
         isbnlike = RE_NORMAL
     elif level == 'strict':
         isbnlike = RE_STRICT
@@ -201,7 +209,7 @@ def get_canonical_isbn(isbnlike, output='bouth'):
     bouth  (default)
 
     """
-    if output not in ('bouth', 'isbn10', 'isbn13'):
+    if output not in ('bouth', 'isbn10', 'isbn13'):  # pragma: no cover
         LOGGER.error('output as no option %s', output)
         return
 
@@ -232,10 +240,13 @@ def get_canonical_isbn(isbnlike, output='bouth'):
             return to_isbn13(cisbn) if len(cisbn) == 10 else cisbn
 
 
-def EAN13(isbnlike):
+def ean13(isbnlike):
     """Transform an `isbnlike` string in an EAN number (canonical ISBN-13)."""
     ib = canonical(isbnlike)
     if len(ib) == 13:
         return ib if is_isbn13(ib) else None
     elif len(ib) == 10:
         return to_isbn13(ib) if is_isbn10(ib) else None
+
+# Alias
+EAN13 = ean13
