@@ -1,14 +1,18 @@
 # -*- coding: utf-8 -*-
 """Extra methods."""
 
-from ._metadata import query
-from ._infogroup import infogroup
-from ._wcated import query as qed
-from ._msk import msk
-from ._gwords import goos
+import re
+
 from ._core import EAN13
-from .dev.bouth23 import u, b2u3
-from .dev.helpers import last_first, cutoff_tokens, File
+from ._cover import cover as gcover
+from ._desc import goo_desc
+from ._editions import editions as eds
+from ._gwords import goos
+from ._infogroup import infogroup
+from ._metadata import query
+from ._msk import msk
+from .dev._bouth23 import b2u3, u
+from .dev.helpers import File, cutoff_tokens, last_first
 
 
 def mask(isbn, separator='-'):
@@ -27,9 +31,12 @@ def info(isbn):
     return infogroup(isbn)
 
 
-def editions(isbn):
-    """Return the list of ISBNs of editions related with this ISBN."""
-    return qed(isbn)
+def editions(isbn, service='wcat'):
+    """Return the list of ISBNs of editions related with this ISBN.
+
+    'service' can have the values 'any', 'merge', 'thingl' and 'wcat' (default)
+    """
+    return eds(isbn, service)
 
 
 def isbn_from_words(words):
@@ -51,19 +58,35 @@ def ren(fp):
         return
     data = meta(isbn)
     author = data.get('Authors', u('UNKNOWN'))
-    if author != u('UNKNOWN'):
+    if author != u('UNKNOWN'):                 # pragma: no cover
         author = last_first(author[0])['last']
     year = data.get('Year', u('UNKNOWN'))
     maxlen = 98 - (20 + len(author) + len(year))
-    title = data.get('Title', u('UNKNOWN'))\
-        .replace(',', ' ')\
-        .replace('.', ' ').strip()
+    title = data.get('Title', u('UNKNOWN'))
+    if title != u('UNKNOWN'):
+        regex1 = re.compile(r'[.,_!?/\\]')
+        regex2 = re.compile('\s\s+')
+        title = regex1.sub(' ', title)
+        title = regex2.sub(' ', title)
+        title = title.strip()
     if title == u('UNKNOWN') or not title:     # pragma: no cover
         return
-    if ' ' in title:
+    if ' ' in title:                           # pragma: no cover
         tokens = title.split(' ')
         stitle = cutoff_tokens(tokens, maxlen)
         title = ' '.join(stitle)
     isbn13 = data.get('ISBN-13', u('UNKNOWN'))
     new_name = "%s%s_%s_%s" % (author, year, title, isbn13)
     return cfp.baserename(b2u3(new_name + cfp.ext))
+
+
+def cover(isbn, size=2, mode='prt'):
+    """Download the cover of the ISBN."""
+    isbn = EAN13(isbn)
+    return gcover(isbn, size=size, mode=mode) if isbn else None
+
+
+def desc(isbn):
+    """Return a descripion of the ISBN."""
+    isbn = EAN13(isbn)
+    return goo_desc(isbn) if isbn else None
