@@ -2,17 +2,17 @@
 """Query the Google Books (JSON API v1) service for metadata."""
 
 import logging
-from .dev.webquery import query as wquery
+
 from .dev import stdmeta
-from .dev.bouth23 import u
-from .dev._exceptions import (DataWrongShapeError,
-                              NoDataForSelectorError,
-                              RecordMappingError)
+from .dev._bouth23 import u
+from .dev._exceptions import (ISBNNotConsistentError,
+                              NoDataForSelectorError, RecordMappingError)
+from .dev.webquery import query as wquery
 
 UA = 'isbnlib (gzip)'
 SERVICE_URL = 'https://www.googleapis.com/books/v1/volumes?q=isbn+{isbn}'\
-    '&fields=items/volumeInfo(title,authors,publisher,publishedDate,language)'\
-    '&maxResults=1'
+    '&fields=items/volumeInfo(title,authors,publisher,publishedDate,language,'\
+    'industryIdentifiers)&maxResults=1'
 LOGGER = logging.getLogger(__name__)
 
 
@@ -32,6 +32,7 @@ def _mapper(isbn, records):
             canonical['Year'] = u('')
         canonical['Language'] = records.get('language', u(''))
     except:           # pragma: no cover
+        LOGGER.debug("RecordMappingError for %s with data %s", isbn, records)
         raise RecordMappingError(isbn)
     # call stdmeta for extra cleanning and validation
     return stdmeta(canonical)
@@ -39,23 +40,23 @@ def _mapper(isbn, records):
 
 def _records(isbn, data):
     """Classify (canonically) the parsed data."""
+    # put the selected data in records
     try:
-        # put the selected data in records
-        records = data['items'][0]['volumeInfo']
-    except:           # pragma: no cover
-        try:
-            extra = data['stat']
-            LOGGER.debug('DataWrongShapeError for %s with data %s',
-                         isbn, extra)
-        except:
-            raise DataWrongShapeError(isbn)
+        recs = data['items'][0]['volumeInfo']
+    except:  # pragma: no cover
+        LOGGER.debug('NoDataForSelectorError for %s', isbn)
         raise NoDataForSelectorError(isbn)
-
+    # consistency check (isbn request = isbn response)
+    if recs:
+        ids = recs.get('industryIdentifiers', '')
+        if isbn not in repr(ids):   # pragma: no cover
+            LOGGER.debug('ISBNNotConsistentError for %s (%s)', isbn, repr(ids))
+            raise ISBNNotConsistentError("%s not in %s" % (isbn, repr(ids)))
     # map canonical <- records
-    return _mapper(isbn, records)
+    return _mapper(isbn, recs)
 
 
 def query(isbn):
     """Query the Google Books (JSON API v1) service for metadata."""
-    data = wquery(SERVICE_URL.format(isbn=isbn), UA)
+    data = wquery(SERVICE_URL.format(isbn=isbn), user_agent=UA)
     return _records(isbn, data)
