@@ -2,14 +2,13 @@
 """Query the Google Books (JSON API v1) for metadata."""
 
 import logging
-from .dev.webquery import query as wquery
-from .dev import stdmeta
-from .dev.bouth23 import u
-from .dev._exceptions import (DataWrongShapeError,
-                              NoDataForSelectorError,
-                              RecordMappingError)
 
-UA = 'isbntools (gzip)'
+from .dev import stdmeta
+from .dev._bouth23 import u
+from .dev._exceptions import (NoDataForSelectorError, RecordMappingError)
+from .dev.webquery import query as wquery
+
+UA = 'isbnlib (gzip)'
 SERVICE_URL = 'https://www.googleapis.com/books/v1/volumes?q={words}'\
     '&fields=items/volumeInfo(title,authors,publisher,publishedDate,'\
     'language,industryIdentifiers)&maxResults=10'
@@ -50,20 +49,14 @@ def _mapper(record):
 
 def _records(words, data):
     """Classify (canonically) the parsed data."""
+    # put the selected data in records
     try:
-        # put the selected data in records
-        records = [d['volumeInfo'] for d in data['items']]
-    except:           # pragma: no cover
-        try:
-            extra = data['stat']
-            LOGGER.debug('DataWrongShapeError for %s with data %s',
-                         words, extra)
-        except:
-            raise DataWrongShapeError(words)
+        recs = [d['volumeInfo'] for d in data['items']]
+    except:  # pragma: no cover
+        LOGGER.debug('NoDataForSelectorError for (%s)', words)
         raise NoDataForSelectorError(words)
-
     # map canonical <- records
-    return [_mapper(r) for r in records if _mapper(r)]
+    return [_mapper(r) for r in recs if _mapper(r)]
 
 
 def query(words):
