@@ -1,12 +1,7 @@
-#!/usr/bin/env python
 # -*- coding: utf-8 -*-
 
-"""Read and write to a dict-like cache.
+"""Read and write to a dict-like cache."""
 
-Implements The Basic Sequence and Mapping Protocol
-Please see http://stackoverflow.com/a/2438926
-
-"""
 
 from collections import MutableMapping
 
@@ -18,6 +13,7 @@ class IMCache(MutableMapping):
     MAXLEN = 1000
 
     def __init__(self, maxlen=MAXLEN, *a, **k):
+        self.filepath = 'IN MEMORY'
         self.maxlen = maxlen
         self.d = dict(*a, **k)
         while len(self) > maxlen:  # pragma: no cache
@@ -32,10 +28,10 @@ class IMCache(MutableMapping):
     def __getitem__(self, k):
         return self.d[k]
 
-    def __delitem__(self, k):
-        del self.d[k]
-
     def __setitem__(self, k, v):
         if k not in self and len(self) == self.maxlen:
             self.popitem()
         self.d[k] = v
+
+    def __delitem__(self, k):
+        del self.d[k]
