@@ -2,8 +2,10 @@
 """Hyphenate an ISBN."""
 
 import logging
+
+from ._core import EAN13, canonical, to_isbn13
 from ._data.data4mask import ranges
-from ._core import canonical, to_isbn13, EAN13
+from ._exceptions import NotValidISBNError
 
 LOGGER = logging.getLogger(__name__)
 
@@ -15,14 +17,15 @@ def msk(isbn, separator='-'):
     ISBN-10 identifiers: country-publisher-title-check
 
     Used the iterative version of the `sliding-window` algorithm.
-    Not pretty but fast! Lines 36-46 implement the search loop.
-    O(n) for n - number of keys, if data structure like ranges in data4mask.py
+    Not pretty, but fast! Lines 42-52 implement the search loop.
+    O(n) for n (number of keys),
+    if data structure like 'ranges' in data4mask.py
     """
     ib = canonical(isbn)
     ean = EAN13(ib)
     if len(ib) not in (10, 13) or ean is None:
-        LOGGER.warning('%s is not a valid ISBN', isbn)
-        return
+        LOGGER.critical('%s is not a valid ISBN', isbn)
+        raise NotValidISBNError(isbn)
 
     isbn10 = False
     if len(ib) == 10:
@@ -37,7 +40,7 @@ def msk(isbn, separator='-'):
     buf = ib[igi:cur + 1]
     group = ib[0:cur] + '-' + buf
 
-    for _ in range(6):
+    for _ in range(6):                             # pragma: no cover
         if group in ranges:
             sevens = ib[cur + 1:cur + 8].ljust(7, '0')
             for l in ranges[group]:
