@@ -2,11 +2,12 @@
 """Query the openlibrary.org service for metadata."""
 
 import logging
-from .dev.webquery import query as wquery
-from .dev import stdmeta
-from .dev.bouth23 import u
-from .dev._exceptions import (NoDataForSelectorError, RecordMappingError)
+import re
 
+from .dev import stdmeta
+from .dev._bouth23 import u
+from .dev._exceptions import NoDataForSelectorError, RecordMappingError
+from .dev.webquery import query as wquery
 
 UA = 'isbnlib (gzip)'
 SERVICE_URL = 'http://openlibrary.org/api/books?bibkeys='\
@@ -27,8 +28,14 @@ def _mapper(isbn, records):
                                 records.get('authors', ({'name': u('')},))]
         canonical['Publisher'] = records.get('publishers',
                                              [{'name': u('')}, ])[0]['name']
-        canonical['Year'] = records.get('publish_date', u(',')).split(',')[1]
-    except:   # pragma: no cover
+        canonical['Year'] = u('')
+        strdate = records.get('publish_date', u(''))
+        if strdate:        # pragma: no cover
+            match = re.search(r'\d{4}', strdate)
+            if match:
+                canonical['Year'] = match.group(0)
+    except:                # pragma: no cover
+        LOGGER.debug("RecordMappingError for %s with data %s", isbn, records)
         raise RecordMappingError(isbn)
     # call stdmeta for extra cleanning and validation
     return stdmeta(canonical)
@@ -40,6 +47,7 @@ def _records(isbn, data):
         # put the selected data in records
         records = data['ISBN:%s' % isbn]
     except:   # pragma: no cover
+        LOGGER.debug('NoDataForSelectorError for %s', isbn)
         raise NoDataForSelectorError(isbn)
 
     # map canonical <- records
@@ -48,5 +56,5 @@ def _records(isbn, data):
 
 def query(isbn):
     """Query the openlibrary.org service for metadata."""
-    data = wquery(SERVICE_URL.format(isbn=isbn), UA)
+    data = wquery(SERVICE_URL.format(isbn=isbn), user_agent=UA)
     return _records(isbn, data)
