@@ -1,12 +1,11 @@
 # -*- coding: utf-8 -*-
-"""Config file for isbntools."""
+"""Config file for isbnlib."""
 
 # --> Import only external modules! <--
 
 
 import socket
 
-
 # Timeouts
 SOCKETS_TIMEOUT = 12    # seconds
 THREADS_TIMEOUT = 11    # seconds
