@@ -1,3 +1,19 @@
+# -*- coding: utf-8 -*-
+from . import bouth23, helpers, vias
+from ._data import Metadata, stdmeta
+from ._exceptions import (DataNotFoundAtServiceError, DataWrongShapeError,
+                          ISBNLibDevException, ISBNLibHTTPError,
+                          ISBNLibURLError, NoAPIKeyError,
+                          NoDataForSelectorError, NotValidMetadataError,
+                          RecordMappingError, ServiceIsDownError)
+from .webquery import WEBQuery
+from .webservice import WEBService
+
+# alias
+ISBNToolsDevException = ISBNLibDevException
+ISBNToolsHTTPError = ISBNLibHTTPError
+ISBNToolsURLError = ISBNLibURLError
+
 __all__ = ('ISBNToolsDevException',
            'ISBNLibDevException',
            'ISBNToolsHTTPError', 'ISBNToolsURLError',
@@ -10,22 +26,3 @@ __all__ = ('ISBNToolsDevException',
            'Metadata', 'stdmeta',
            'WEBService', 'WEBQuery', 'vias', 'bouth23', 'helpers'
            )
-
-
-from .webservice import WEBService
-from .webquery import WEBQuery
-from ._exceptions import (ISBNLibDevException,
-                          ISBNLibHTTPError, ISBNLibURLError,
-                          DataNotFoundAtServiceError,
-                          NoDataForSelectorError, ServiceIsDownError,
-                          DataWrongShapeError, NotValidMetadataError,
-                          RecordMappingError, NoAPIKeyError)
-from ._data import Metadata, stdmeta
-from . import vias
-from . import bouth23
-from . import helpers
-
-# alias
-ISBNToolsDevException = ISBNLibDevException
-ISBNToolsHTTPError = ISBNLibHTTPError
-ISBNToolsURLError = ISBNLibURLError
