@@ -2,11 +2,13 @@
 
 """Helper module to work with files."""
 
-import re
-import os
-import logging
+
 import fnmatch
-from stat import S_IRUSR, S_IWUSR, S_IRGRP, S_IWGRP, S_IROTH, S_IWOTH
+import logging
+import os
+import re
+from stat import S_IRGRP, S_IROTH, S_IRUSR, S_IWGRP, S_IWOTH, S_IWUSR
+
 from ._exceptions import FileNotFoundError
 
 MAXLEN = 120
@@ -17,7 +19,7 @@ MODE666 = S_IRUSR | S_IWUSR | S_IRGRP | S_IWGRP | S_IROTH | S_IWOTH
 
 class File(object):
 
-    """Easy manipulation of files on the SAME directory."""
+    """Easy manipulation of files in the SAME directory."""
 
     def __init__(self, fp):
         """Set and validate the basic properties."""
@@ -78,8 +80,8 @@ class File(object):
         if new_basename not in self.siblings():
             try:
                 os.rename(self.basename, new_basename)
-            except OSError as e:
-                LOGGER.critical("%s", e.message)
+            except OSError as err:
+                LOGGER.critical("%s", err.message)
                 return False
             self.basename = new_basename
             self.name = name
