@@ -7,8 +7,8 @@
 import re
 import uuid
 from string import Template
-from ._helpers import last_first
 
+from ._helpers import last_first
 
 bibtex = r"""@book{$ISBN,
      title = {$Title},
@@ -48,11 +48,11 @@ msword = r'''<b:Source xmlns:b="http://schemas.microsoft.com/office/'''\
 </b:Source>'''
 
 json = r'''{"type": "book",
-"title": "$Title",
-"author": [$AUTHORS],
-"year": "$Year",
+     "title": "$Title",
+    "author": [$AUTHORS],
+      "year": "$Year",
 "identifier": [{"type": "ISBN", "id": "$ISBN"}],
-"publisher": "$Publisher"}'''
+ "publisher": "$Publisher"}'''
 
 opf = r"""<?xml version='1.0' encoding='utf-8'?>
 <package version="2.0" xmlns="http://www.idpf.org/2007/opf" unique-identifier="uuid_id">
@@ -64,7 +64,7 @@ opf = r"""<?xml version='1.0' encoding='utf-8'?>
     $AUTHORS
     <dc:publisher>$Publisher</dc:publisher>
     <dc:date>$Year</dc:date>
-    <dc:contributor opf:file-as="isbntools" opf:role="mdc">isbntools [http://github.com/xlcnd/isbntools]</dc:contributor>
+    <dc:contributor opf:file-as="isbnlib" opf:role="mdc">isbnlib [http://github.com/xlcnd/isbnlib]</dc:contributor>
   </metadata>
 </package>"""
 
