@@ -1,9 +1,12 @@
 # -*- coding: utf-8 -*-
 """Query web services."""
 
-import logging
 import gzip
-from .bouth23 import s, bstream
+import logging
+
+from ._bouth23 import bstream, s
+from ._exceptions import ISBNLibHTTPError, ISBNLibURLError
+
 try:                     # pragma: no cover
     from urllib.parse import urlencode
     from urllib.request import Request, urlopen
@@ -11,7 +14,6 @@ try:                     # pragma: no cover
 except ImportError:      # pragma: no cover
     from urllib import urlencode
     from urllib2 import Request, urlopen, HTTPError, URLError
-from ._exceptions import ISBNLibHTTPError, ISBNLibURLError
 
 UA = 'isbnlib (gzip)'
 LOGGER = logging.getLogger(__name__)
@@ -42,10 +44,12 @@ class WEBService(object):
         except HTTPError as e:  # pragma: no cover
             LOGGER.critical('ISBNLibHTTPError for %s with code %s [%s]',
                             self._url, e.code, e.msg)
-            if e.code in ('401', '403', '429'):
-                raise ISBNLibHTTPError('Are you are making many requests?')
-            if e.code in ('502', '504'):
-                raise ISBNLibHTTPError('Service temporarily unavailable!')
+            if e.code in (401, 403, 429):
+                raise ISBNLibHTTPError('%s Are you making many requests?'
+                                       % e.code)
+            if e.code in (502, 504):
+                raise ISBNLibHTTPError('%s Service temporarily unavailable!'
+                                       % e.code)
             raise ISBNLibHTTPError('(%s) %s' % (e.code, e.msg))
         except URLError as e:   # pragma: no cover
             LOGGER.critical('ISBNLibURLError for %s with reason %s',
