@@ -1,16 +1,16 @@
 # -*- coding: utf-8 -*-
+
 """Registry for metadata services, formatters and cache."""
 
 
-from . import _wcat as wcat
 from . import _goob as goob
+from . import _isbndb as isbndb
 from . import _merge as merge
 from . import _openl as openl
-from . import _isbndb as isbndb
+from . import _wcat as wcat
 from ._imcache import IMCache
 from .dev._fmt import fmtbib
 
-
 # SERVICES
 
 services = {'default': merge.query,
@@ -43,8 +43,7 @@ bibformatters = {'default': lambda x: fmtbib('labels', x),
                  'refworks': lambda x: fmtbib('refworks', x),
                  'msword': lambda x: fmtbib('msword', x),
                  'json': lambda x: fmtbib('json', x),
-                 'opf': lambda x: fmtbib('opf', x)
-                 }
+                 'opf': lambda x: fmtbib('opf', x)}   # pragma: no cover
 
 
 def setdefaultbibformatter(name):              # pragma: no cover
@@ -70,3 +69,19 @@ def set_cache(cache):                 # pragma: no cover
     """Set cache for metadata."""
     global metadata_cache
     metadata_cache = cache
+
+covers_cache = None                   # should be an instance
+
+
+def set_covers_cache(cache):          # pragma: no cover
+    """Set cache for covers."""
+    global covers_cache
+    covers_cache = cache
+
+custom_cache = None                   # should be an instance
+
+
+def set_custom_cache(cache):          # pragma: no cover
+    """Set a 'spare' cache."""
+    global custom_cache
+    custom_cache = cache
