@@ -1,13 +1,14 @@
 # -*- coding: utf-8 -*-
 # flake8: noqa
 # pylint: skip-file
+
 """
 nose tests
 """
 
-from ..dev._fmt import fmtbib
 from nose.tools import assert_equals
-from ..dev.bouth23 import u
+from ..dev._bouth23 import u
+from ..dev._fmt import fmtbib
 
 
 canonical = {
@@ -20,10 +21,11 @@ canonical = {
              }
 
 def test_fmtbib():
+    """Test the formating into several bibliographic formats."""
     assert_equals(len(fmtbib("bibtex", canonical)), 182)
     assert_equals(len(fmtbib("labels", canonical)), 158)
     assert_equals(len(fmtbib("endnote", canonical)), 103)
     assert_equals(len(fmtbib("msword", canonical)), 485)
-    assert_equals(len(fmtbib("json", canonical)), 213)
+    assert_equals(len(fmtbib("json", canonical)), 229)
     assert_equals(len(fmtbib("refworks", canonical)), 130)
-    assert_equals(len(fmtbib("opf", canonical)), 867)
+    assert_equals(len(fmtbib("opf", canonical)), 861)
