@@ -1,7 +1,7 @@
-#!/usr/bin/env python
 # -*- coding: utf-8 -*-
 # flake8: noqa
 # pylint: skip-file
+
 """
 nose tests
 """
@@ -11,5 +11,6 @@ from nose.tools import assert_equals
 
 
 def test_unicode_to_utf8tex():
+    """Test 'unicode_to_utf8tex' identity transformation."""
     assert_equals(unicode_to_utf8tex(u"\u00E2 \u00F5"), b"\^{a}\space \~{o}")
     assert_equals(unicode_to_utf8tex(u"\u00E2 \u00F5", (b"\\space ",)), b"\^{a} \~{o}")
